% ------------------------------------------------------------------------------
% --
% -- Dies ist die LaTeX-Vorlage für den Workshop Methoden und
% -- Beschreibungssprachen zur Modellierung und Verifikation von Schaltungen
% -- und Systemen.
% --
% -- Autor: Philipp Ittershagen <philipp.ittershagen@uni-oldenburg.de>
% --
% -- OFFIS Institut für Informatik  
% -- Escherweg 2
% -- 26121 Oldenburg
% --
% -- www  : http://offis.de/
% -- phone: +49 (441) 9722-0
% -- fax  : +49 (441) 9722-102
% --
% -- Ueberarbeitung durch: Ralf Wimmer
% --
% -- Albert-Ludwigs-Universitaet Freiburg
% -- Georges-Koehler-Allee 51-01-033
% -- 79110 Freiburg
% --
% -- Hinweise zur Art der Dokumentation dieser Vorlage:
% --
% -- Informationen, die vom Benutzer verändert werden sollten, sind durch
% -- Kommentarblöcke mit einem Token (:user:) gekennzeichnet.
% -- Bis auf die Dokumentoptionen befinden sich alle anderen für den Benutzer
% -- relevanten Optionen am Ende der LaTeX-Definitionen.
% --
% ------------------------------------------------------------------------------
\ProvidesClass{mbmv}

\LoadClass[%
a4paper,                % DIN-A4 Größe
fontsize=12pt,          % 12pt als Standard-Schriftgröße verwenden. Andere
                        % Größen (\Large etc) orientieren sich an diesem Wert
headings=small,         % Überschriften kleiner darstellen
captions=tableheading,  % Überschrift statt Unterschrift bei Tabellen
numbers=endperiod,      % Punkt am Ende von Gliederungsnummern
abstracton              % Setze Überschrift über das Abstract
]{scrartcl}


% ------------------------------------------------------------------------------
% -- Definition der Seitenränder
% ------------------------------------------------------------------------------
\RequirePackage[%
left=0.98in,
top=0.79in,
right=0.79in,
bottom=1.18in,
includefoot
]{geometry}


% Eingabemethode (z.B. utf8x oder latin1)
\RequirePackage[utf8x]{inputenc}

% Benötigt, um Abstand zwischen Über/Unterschriften und Bild/Tabelle zu
% verringern
\RequirePackage{caption}

% If/Else-Blöcke ermöglichen
\RequirePackage{ifthen}

% Wird zum Einbinden von Graphiken benötigt
\RequirePackage{graphicx}

% Pakete für die Schriftart(en)
\RequirePackage{textcomp}
\RequirePackage{newtxtext}
\RequirePackage{newtxmath}

% Für die bessere Darstellung von Tabellen
\RequirePackage{booktabs}

% Wird für \prependto@macro benötigt
\RequirePackage{moredefs}

% URLs anzeigen
\RequirePackage{url}



% ------------------------------------------------------------------------------
% -- Definition der zusätzlichen Dokumentoptionen "blinded" und
% -- "ngerman,german,english"
% ------------------------------------------------------------------------------
\newboolean{blindauthors} \setboolean{blindauthors}{false}
\newboolean{german}       \setboolean{german}{false}
\DeclareOption{blinded}{\setboolean{blindauthors}{true}}
\DeclareOption{ngerman}{\setboolean{german}{true}}
\DeclareOption{german}{\setboolean{german}{true}}
\DeclareOption{english}{\setboolean{german}{false}}
\ProcessOptions


% ------------------------------------------------------------------------------
% -- Abschnittsname der Sprachwahl entsprechend setzen
% ------------------------------------------------------------------------------
\ifthenelse{\boolean{german}}
  {\newcommand{\sectionname}{Abschnitt}\RequirePackage[ngerman]{babel}}
  {\newcommand{\sectionname}{Section}\RequirePackage[english]{babel}}

% Literatur einbinden können
\RequirePackage{babelbib}


% ------------------------------------------------------------------------------
% -- URLs kleiner darstellen
% ------------------------------------------------------------------------------
\makeatletter
\def\url@smallstyle{%
\@ifundefined{selectfont}{%
\def\UrlFont{\sf}}{\def\UrlFont{\small\ttfamily}}}
\makeatother
\urlstyle{small}


% ------------------------------------------------------------------------------
% -- Paper-Titel in 16pt anzeigen.
% ------------------------------------------------------------------------------
\makeatletter
\prependto@macro{\maketitle}{%
\let\huge\Large\let\Large\normalsize\let\large\normalsize}
\makeatother


% ------------------------------------------------------------------------------
% -- Optionales Ausblenden der Autoren ermöglichen
% ------------------------------------------------------------------------------
\ifthenelse{\boolean{blindauthors}}{%
\newcommand{\authorblock}[1]{%
\ldots blinded for review \ldots \\
\ldots \\
\ldots \\
\ldots
}}{%
\newcommand{\authorblock}[1]{ #1 }
}

% ------------------------------------------------------------------------------
% -- Einfachere Referenzierung von Tabellen, Abbildungen, etc.
% ------------------------------------------------------------------------------
\newcommand{\refsec}[1]{\sectionname~\ref{sec:#1}}    % -> Section X
\newcommand{\reffig}[1]{\figurename~\ref{fig:#1}}      % -> Figure  X
\newcommand{\reftab}[1]{\tablename~\ref{tab:#1}}       % -> Table X
\newcommand{\reflst}[1]{\lstlistingname~\ref{lst:#1}} % -> Listing X
\newcommand{\refeq}[1]{\equationname~\ref{eq:#1}}      % -> Equation X
\newcommand{\refdef}[1]{Def.~\ref{def:#1}}             % -> Definition X

% ------------------------------------------------------------------------------
% -- Stil der Literaturangaben
% ------------------------------------------------------------------------------
\bibliographystyle{babplain}

% ------------------------------------------------------------------------------
% -- Überschriften auf normale Größe setzen (12pt).
% ------------------------------------------------------------------------------
\setkomafont{disposition}{\normalfont\bfseries}
\setkomafont{caption}{\small}
\setkomafont{captionlabel}{\bfseries\small}
\renewenvironment{abstract}{\quote\small\textbf{Abstract.}~\ignorespaces}{\endquote}

% ------------------------------------------------------------------------------
% -- Abstand zwischen Über/Unterschriften und Bild/Tabelle verringern
% ------------------------------------------------------------------------------
\setlength{\abovecaptionskip}{-.75ex}
\setlength{\belowcaptionskip}{-.75ex}


% ------------------------------------------------------------------------------
% -- Stil der Seite wird nur manuell festgelegt, daher wird empty als Stil
% -- eingestellt.
% ------------------------------------------------------------------------------
\renewcommand*{\titlepagestyle}{empty}
\pagestyle{empty}
\date{}

\endinput
